@@ -1,5 +1,5 @@
-from middleware import Middleware
-from errors import AppException
+from arc.middleware import Middleware
+from arc.errors import AppException
 
 
 class DefaultMiddleware(Middleware):
@@ -18,3 +18,9 @@ class DefaultExceptionHandler:
         response.status_code = 500
         response.body = self.app.template(
             "error-500.html", context={"error": str(error)})
+
+class TestClass:
+    def __init__(self):
+        self.test()
+    def test(self):
+        print("TEST")
\ No newline at end of file
